@@ -76,10 +76,10 @@ class KBounceGameWidget : public QGraphicsView
     protected:
 	virtual void resizeEvent( QResizeEvent* event );
 	virtual void mouseReleaseEvent( QMouseEvent* event );
-	void renderBackground();
+	void focusOutEvent(QFocusEvent *event);
 	void closeLevel();
 	void newLevel();
-
+	void updateCursor();
 	void redraw();
         void setGameDifficulty(const KgDifficultyLevel *);
 
